'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def add_permission(QueueUrl=None, Label=None, AWSAccountIds=None, Actions=None):
    """
    Adds a permission to a queue for a specific principal . This allows sharing access to the queue.
    When you create a queue, you have full control access rights for the queue. Only you, the owner of the queue, can grant or deny permissions to the queue. For more information about these permissions, see Allow Developers to Write Messages to a Shared Queue in the Amazon Simple Queue Service Developer Guide .
    Some actions take lists of parameters. These lists are specified using the param.n notation. Values of n are integers starting from 1. For example, a parameter list with two elements looks like this:
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.add_permission(
        QueueUrl='string',
        Label='string',
        AWSAccountIds=[
            'string',
        ],
        Actions=[
            'string',
        ]
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the Amazon SQS queue to which permissions are added.\nQueue URLs and names are case-sensitive.\n

    :type Label: string
    :param Label: [REQUIRED]\nThe unique identification of the permission you\'re setting (for example, AliceSendMessage ). Maximum 80 characters. Allowed characters include alphanumeric characters, hyphens (- ), and underscores (_ ).\n

    :type AWSAccountIds: list
    :param AWSAccountIds: [REQUIRED]\nThe AWS account number of the principal who is given permission. The principal must have an AWS account, but does not need to be signed up for Amazon SQS. For information about locating the AWS account identification, see Your AWS Identifiers in the Amazon Simple Queue Service Developer Guide .\n\n(string) --\n\n

    :type Actions: list
    :param Actions: [REQUIRED]\nThe action the client wants to allow for the specified principal. Valid values: the name of any action or * .\nFor more information about these actions, see Overview of Managing Access Permissions to Your Amazon Simple Queue Service Resource in the Amazon Simple Queue Service Developer Guide .\nSpecifying SendMessage , DeleteMessage , or ChangeMessageVisibility for ActionName.n also grants permissions for the corresponding batch versions of those actions: SendMessageBatch , DeleteMessageBatch , and ChangeMessageVisibilityBatch .\n\n(string) --\n\n

    :returns: 
    QueueUrl (string) -- [REQUIRED]
    The URL of the Amazon SQS queue to which permissions are added.
    Queue URLs and names are case-sensitive.
    
    Label (string) -- [REQUIRED]
    The unique identification of the permission you\'re setting (for example, AliceSendMessage ). Maximum 80 characters. Allowed characters include alphanumeric characters, hyphens (- ), and underscores (_ ).
    
    AWSAccountIds (list) -- [REQUIRED]
    The AWS account number of the principal who is given permission. The principal must have an AWS account, but does not need to be signed up for Amazon SQS. For information about locating the AWS account identification, see Your AWS Identifiers in the Amazon Simple Queue Service Developer Guide .
    
    (string) --
    
    
    Actions (list) -- [REQUIRED]
    The action the client wants to allow for the specified principal. Valid values: the name of any action or * .
    For more information about these actions, see Overview of Managing Access Permissions to Your Amazon Simple Queue Service Resource in the Amazon Simple Queue Service Developer Guide .
    Specifying SendMessage , DeleteMessage , or ChangeMessageVisibility for ActionName.n also grants permissions for the corresponding batch versions of those actions: SendMessageBatch , DeleteMessageBatch , and ChangeMessageVisibilityBatch .
    
    (string) --
    
    
    
    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def change_message_visibility(QueueUrl=None, ReceiptHandle=None, VisibilityTimeout=None):
    """
    Changes the visibility timeout of a specified message in a queue to a new value. The default visibility timeout for a message is 30 seconds. The minimum is 0 seconds. The maximum is 12 hours. For more information, see Visibility Timeout in the Amazon Simple Queue Service Developer Guide .
    For example, you have a message with a visibility timeout of 5 minutes. After 3 minutes, you call ChangeMessageVisibility with a timeout of 10 minutes. You can continue to call ChangeMessageVisibility to extend the visibility timeout to the maximum allowed time. If you try to extend the visibility timeout beyond the maximum, your request is rejected.
    An Amazon SQS message has three basic states:
    A message is considered to be stored after it is sent to a queue by a producer, but not yet received from the queue by a consumer (that is, between states 1 and 2). There is no limit to the number of stored messages. A message is considered to be in flight after it is received from a queue by a consumer, but not yet deleted from the queue (that is, between states 2 and 3). There is a limit to the number of inflight messages.
    Limits that apply to inflight messages are unrelated to the unlimited number of stored messages.
    For most standard queues (depending on queue traffic and message backlog), there can be a maximum of approximately 120,000 inflight messages (received from a queue by a consumer, but not yet deleted from the queue). If you reach this limit, Amazon SQS returns the OverLimit error message. To avoid reaching the limit, you should delete messages from the queue after they\'re processed. You can also increase the number of queues you use to process your messages. To request a limit increase, file a support request .
    For FIFO queues, there can be a maximum of 20,000 inflight messages (received from a queue by a consumer, but not yet deleted from the queue). If you reach this limit, Amazon SQS returns no error messages.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.change_message_visibility(
        QueueUrl='string',
        ReceiptHandle='string',
        VisibilityTimeout=123
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the Amazon SQS queue whose message\'s visibility is changed.\nQueue URLs and names are case-sensitive.\n

    :type ReceiptHandle: string
    :param ReceiptHandle: [REQUIRED]\nThe receipt handle associated with the message whose visibility timeout is changed. This parameter is returned by the `` ReceiveMessage `` action.\n

    :type VisibilityTimeout: integer
    :param VisibilityTimeout: [REQUIRED]\nThe new value for the message\'s visibility timeout (in seconds). Values values: 0 to 43200 . Maximum: 12 hours.\n

    :returns: 
    QueueUrl (string) -- [REQUIRED]
    The URL of the Amazon SQS queue whose message\'s visibility is changed.
    Queue URLs and names are case-sensitive.
    
    ReceiptHandle (string) -- [REQUIRED]
    The receipt handle associated with the message whose visibility timeout is changed. This parameter is returned by the ``  ReceiveMessage `` action.
    
    VisibilityTimeout (integer) -- [REQUIRED]
    The new value for the message\'s visibility timeout (in seconds). Values values: 0 to 43200 . Maximum: 12 hours.
    
    
    """
    pass

def change_message_visibility_batch(QueueUrl=None, Entries=None):
    """
    Changes the visibility timeout of multiple messages. This is a batch version of ``  ChangeMessageVisibility .`` The result of the action on each message is reported individually in the response. You can send up to 10 ``  ChangeMessageVisibility `` requests with each ChangeMessageVisibilityBatch action.
    Some actions take lists of parameters. These lists are specified using the param.n notation. Values of n are integers starting from 1. For example, a parameter list with two elements looks like this:
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.change_message_visibility_batch(
        QueueUrl='string',
        Entries=[
            {
                'Id': 'string',
                'ReceiptHandle': 'string',
                'VisibilityTimeout': 123
            },
        ]
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the Amazon SQS queue whose messages\' visibility is changed.\nQueue URLs and names are case-sensitive.\n

    :type Entries: list
    :param Entries: [REQUIRED]\nA list of receipt handles of the messages for which the visibility timeout must be changed.\n\n(dict) --Encloses a receipt handle and an entry id for each message in `` ChangeMessageVisibilityBatch .``\n\nWarning\n\nAll of the following list parameters must be prefixed with ChangeMessageVisibilityBatchRequestEntry.n , where n is an integer value starting with 1 . For example, a parameter list for this action might look like this:\n&ChangeMessageVisibilityBatchRequestEntry.1.Id=change_visibility_msg_2\n&ChangeMessageVisibilityBatchRequestEntry.1.ReceiptHandle=your_receipt_handle\n&ChangeMessageVisibilityBatchRequestEntry.1.VisibilityTimeout=45\n\n\nId (string) -- [REQUIRED]An identifier for this particular receipt handle used to communicate the result.\n\nNote\nThe Id s of a batch request need to be unique within a request\n\n\nReceiptHandle (string) -- [REQUIRED]A receipt handle.\n\nVisibilityTimeout (integer) --The new value (in seconds) for the message\'s visibility timeout.\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'Successful': [
        {
            'Id': 'string'
        },
    ],
    'Failed': [
        {
            'Id': 'string',
            'SenderFault': True|False,
            'Code': 'string',
            'Message': 'string'
        },
    ]
}


Response Structure

(dict) --
For each message in the batch, the response contains a ``  ChangeMessageVisibilityBatchResultEntry `` tag if the message succeeds or a ``  BatchResultErrorEntry `` tag if the message fails.

Successful (list) --
A list of ``  ChangeMessageVisibilityBatchResultEntry `` items.

(dict) --
Encloses the Id of an entry in ``  ChangeMessageVisibilityBatch .``

Id (string) --
Represents a message whose visibility timeout has been changed successfully.





Failed (list) --
A list of ``  BatchResultErrorEntry `` items.

(dict) --
Gives a detailed description of the result of an action on each entry in the request.

Id (string) --
The Id of an entry in a batch request.

SenderFault (boolean) --
Specifies whether the error happened due to the producer.

Code (string) --
An error code representing why the action failed on this entry.

Message (string) --
A message explaining why the action failed on this entry.











Exceptions

SQS.Client.exceptions.TooManyEntriesInBatchRequest
SQS.Client.exceptions.EmptyBatchRequest
SQS.Client.exceptions.BatchEntryIdsNotDistinct
SQS.Client.exceptions.InvalidBatchEntryId


    :return: {
        'Successful': [
            {
                'Id': 'string'
            },
        ],
        'Failed': [
            {
                'Id': 'string',
                'SenderFault': True|False,
                'Code': 'string',
                'Message': 'string'
            },
        ]
    }
    
    
    :returns: 
    SQS.Client.exceptions.TooManyEntriesInBatchRequest
    SQS.Client.exceptions.EmptyBatchRequest
    SQS.Client.exceptions.BatchEntryIdsNotDistinct
    SQS.Client.exceptions.InvalidBatchEntryId
    
    """
    pass

def create_queue(QueueName=None, Attributes=None, tags=None):
    """
    Creates a new standard or FIFO queue. You can pass one or more attributes in the request. Keep the following caveats in mind:
    To successfully create a new queue, you must provide a queue name that adheres to the limits related to queues and is unique within the scope of your queues.
    To get the queue URL, use the ``  GetQueueUrl `` action. ``  GetQueueUrl `` requires only the QueueName parameter. be aware of existing queue names:
    Some actions take lists of parameters. These lists are specified using the param.n notation. Values of n are integers starting from 1. For example, a parameter list with two elements looks like this:
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_queue(
        QueueName='string',
        Attributes={
            'string': 'string'
        },
        tags={
            'string': 'string'
        }
    )
    
    
    :type QueueName: string
    :param QueueName: [REQUIRED]\nThe name of the new queue. The following limits apply to this name:\n\nA queue name can have up to 80 characters.\nValid values: alphanumeric characters, hyphens (- ), and underscores (_ ).\nA FIFO queue name must end with the .fifo suffix.\n\nQueue URLs and names are case-sensitive.\n

    :type Attributes: dict
    :param Attributes: A map of attributes with their corresponding values.\nThe following lists the names, descriptions, and values of the special request parameters that the CreateQueue action uses:\n\nDelaySeconds - The length of time, in seconds, for which the delivery of all messages in the queue is delayed. Valid values: An integer from 0 to 900 seconds (15 minutes). Default: 0.\nMaximumMessageSize - The limit of how many bytes a message can contain before Amazon SQS rejects it. Valid values: An integer from 1,024 bytes (1 KiB) to 262,144 bytes (256 KiB). Default: 262,144 (256 KiB).\nMessageRetentionPeriod - The length of time, in seconds, for which Amazon SQS retains a message. Valid values: An integer from 60 seconds (1 minute) to 1,209,600 seconds (14 days). Default: 345,600 (4 days).\nPolicy - The queue\'s policy. A valid AWS policy. For more information about policy structure, see Overview of AWS IAM Policies in the Amazon IAM User Guide .\nReceiveMessageWaitTimeSeconds - The length of time, in seconds, for which a `` ReceiveMessage `` action waits for a message to arrive. Valid values: An integer from 0 to 20 (seconds). Default: 0.\nRedrivePolicy - The string that includes the parameters for the dead-letter queue functionality of the source queue. For more information about the redrive policy and dead-letter queues, see Using Amazon SQS Dead-Letter Queues in the Amazon Simple Queue Service Developer Guide .\ndeadLetterTargetArn - The Amazon Resource Name (ARN) of the dead-letter queue to which Amazon SQS moves messages after the value of maxReceiveCount is exceeded.\nmaxReceiveCount - The number of times a message is delivered to the source queue before being moved to the dead-letter queue. When the ReceiveCount for a message exceeds the maxReceiveCount for a queue, Amazon SQS moves the message to the dead-letter-queue.\n\n\n\n\nNote\nThe dead-letter queue of a FIFO queue must also be a FIFO queue. Similarly, the dead-letter queue of a standard queue must also be a standard queue.\n\n\nVisibilityTimeout - The visibility timeout for the queue, in seconds. Valid values: An integer from 0 to 43,200 (12 hours). Default: 30. For more information about the visibility timeout, see Visibility Timeout in the Amazon Simple Queue Service Developer Guide .\n\nThe following attributes apply only to server-side-encryption :\n\nKmsMasterKeyId - The ID of an AWS-managed customer master key (CMK) for Amazon SQS or a custom CMK. For more information, see Key Terms . While the alias of the AWS-managed CMK for Amazon SQS is always alias/aws/sqs , the alias of a custom CMK can, for example, be ``alias/MyAlias `` . For more examples, see KeyId in the AWS Key Management Service API Reference .\nKmsDataKeyReusePeriodSeconds - The length of time, in seconds, for which Amazon SQS can reuse a data key to encrypt or decrypt messages before calling AWS KMS again. An integer representing seconds, between 60 seconds (1 minute) and 86,400 seconds (24 hours). Default: 300 (5 minutes). A shorter time period provides better security but results in more calls to KMS which might incur charges after Free Tier. For more information, see How Does the Data Key Reuse Period Work? .\n\nThe following attributes apply only to FIFO (first-in-first-out) queues :\n\nFifoQueue - Designates a queue as FIFO. Valid values: true , false . If you don\'t specify the FifoQueue attribute, Amazon SQS creates a standard queue. You can provide this attribute only during queue creation. You can\'t change it for an existing queue. When you set this attribute, you must also provide the MessageGroupId for your messages explicitly. For more information, see FIFO Queue Logic in the Amazon Simple Queue Service Developer Guide .\nContentBasedDeduplication - Enables content-based deduplication. Valid values: true , false . For more information, see Exactly-Once Processing in the Amazon Simple Queue Service Developer Guide .\nEvery message must have a unique MessageDeduplicationId ,\nYou may provide a MessageDeduplicationId explicitly.\nIf you aren\'t able to provide a MessageDeduplicationId and you enable ContentBasedDeduplication for your queue, Amazon SQS uses a SHA-256 hash to generate the MessageDeduplicationId using the body of the message (but not the attributes of the message).\nIf you don\'t provide a MessageDeduplicationId and the queue doesn\'t have ContentBasedDeduplication set, the action fails with an error.\nIf the queue has ContentBasedDeduplication set, your MessageDeduplicationId overrides the generated one.\n\n\nWhen ContentBasedDeduplication is in effect, messages with identical content sent within the deduplication interval are treated as duplicates and only one copy of the message is delivered.\nIf you send one message with ContentBasedDeduplication enabled and then another message with a MessageDeduplicationId that is the same as the one generated for the first MessageDeduplicationId , the two messages are treated as duplicates and only one copy of the message is delivered.\n\n\n\n\n(string) --\n(string) --\n\n\n\n

    :type tags: dict
    :param tags: Add cost allocation tags to the specified Amazon SQS queue. For an overview, see Tagging Your Amazon SQS Queues in the Amazon Simple Queue Service Developer Guide .\nWhen you use queue tags, keep the following guidelines in mind:\n\nAdding more than 50 tags to a queue isn\'t recommended.\nTags don\'t have any semantic meaning. Amazon SQS interprets tags as character strings.\nTags are case-sensitive.\nA new tag with a key identical to that of an existing tag overwrites the existing tag.\n\nFor a full list of tag restrictions, see Limits Related to Queues in the Amazon Simple Queue Service Developer Guide .\n\nNote\nTo be able to tag a queue on creation, you must have the sqs:CreateQueue and sqs:TagQueue permissions.\nCross-account permissions don\'t apply to this action. For more information, see Grant Cross-Account Permissions to a Role and a User Name in the Amazon Simple Queue Service Developer Guide .\n\n\n(string) --\n(string) --\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'QueueUrl': 'string'
}


Response Structure

(dict) --
Returns the QueueUrl attribute of the created queue.

QueueUrl (string) --
The URL of the created Amazon SQS queue.







Exceptions

SQS.Client.exceptions.QueueDeletedRecently
SQS.Client.exceptions.QueueNameExists


    :return: {
        'QueueUrl': 'string'
    }
    
    
    :returns: 
    If you don\'t provide a value for an attribute, the queue is created with the default value for the attribute.
    If you delete a queue, you must wait at least 60 seconds before creating a queue with the same name.
    
    """
    pass

def delete_message(QueueUrl=None, ReceiptHandle=None):
    """
    Deletes the specified message from the specified queue. To select the message to delete, use the ReceiptHandle of the message (not the MessageId which you receive when you send the message). Amazon SQS can delete a message from a queue even if a visibility timeout setting causes the message to be locked by another consumer. Amazon SQS automatically deletes messages left in a queue longer than the retention period configured for the queue.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_message(
        QueueUrl='string',
        ReceiptHandle='string'
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the Amazon SQS queue from which messages are deleted.\nQueue URLs and names are case-sensitive.\n

    :type ReceiptHandle: string
    :param ReceiptHandle: [REQUIRED]\nThe receipt handle associated with the message to delete.\n

    :returns: 
    SQS.Client.exceptions.InvalidIdFormat
    SQS.Client.exceptions.ReceiptHandleIsInvalid
    
    """
    pass

def delete_message_batch(QueueUrl=None, Entries=None):
    """
    Deletes up to ten messages from the specified queue. This is a batch version of ``  DeleteMessage .`` The result of the action on each message is reported individually in the response.
    Some actions take lists of parameters. These lists are specified using the param.n notation. Values of n are integers starting from 1. For example, a parameter list with two elements looks like this:
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_message_batch(
        QueueUrl='string',
        Entries=[
            {
                'Id': 'string',
                'ReceiptHandle': 'string'
            },
        ]
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the Amazon SQS queue from which messages are deleted.\nQueue URLs and names are case-sensitive.\n

    :type Entries: list
    :param Entries: [REQUIRED]\nA list of receipt handles for the messages to be deleted.\n\n(dict) --Encloses a receipt handle and an identifier for it.\n\nId (string) -- [REQUIRED]An identifier for this particular receipt handle. This is used to communicate the result.\n\nNote\nThe Id s of a batch request need to be unique within a request\n\n\nReceiptHandle (string) -- [REQUIRED]A receipt handle.\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'Successful': [
        {
            'Id': 'string'
        },
    ],
    'Failed': [
        {
            'Id': 'string',
            'SenderFault': True|False,
            'Code': 'string',
            'Message': 'string'
        },
    ]
}


Response Structure

(dict) --
For each message in the batch, the response contains a ``  DeleteMessageBatchResultEntry `` tag if the message is deleted or a ``  BatchResultErrorEntry `` tag if the message can\'t be deleted.

Successful (list) --
A list of ``  DeleteMessageBatchResultEntry `` items.

(dict) --
Encloses the Id of an entry in ``  DeleteMessageBatch .``

Id (string) --
Represents a successfully deleted message.





Failed (list) --
A list of ``  BatchResultErrorEntry `` items.

(dict) --
Gives a detailed description of the result of an action on each entry in the request.

Id (string) --
The Id of an entry in a batch request.

SenderFault (boolean) --
Specifies whether the error happened due to the producer.

Code (string) --
An error code representing why the action failed on this entry.

Message (string) --
A message explaining why the action failed on this entry.











Exceptions

SQS.Client.exceptions.TooManyEntriesInBatchRequest
SQS.Client.exceptions.EmptyBatchRequest
SQS.Client.exceptions.BatchEntryIdsNotDistinct
SQS.Client.exceptions.InvalidBatchEntryId


    :return: {
        'Successful': [
            {
                'Id': 'string'
            },
        ],
        'Failed': [
            {
                'Id': 'string',
                'SenderFault': True|False,
                'Code': 'string',
                'Message': 'string'
            },
        ]
    }
    
    
    :returns: 
    SQS.Client.exceptions.TooManyEntriesInBatchRequest
    SQS.Client.exceptions.EmptyBatchRequest
    SQS.Client.exceptions.BatchEntryIdsNotDistinct
    SQS.Client.exceptions.InvalidBatchEntryId
    
    """
    pass

def delete_queue(QueueUrl=None):
    """
    Deletes the queue specified by the QueueUrl , regardless of the queue\'s contents. If the specified queue doesn\'t exist, Amazon SQS returns a successful response.
    When you delete a queue, the deletion process takes up to 60 seconds. Requests you send involving that queue during the 60 seconds might succeed. For example, a ``  SendMessage `` request might succeed, but after 60 seconds the queue and the message you sent no longer exist.
    When you delete a queue, you must wait at least 60 seconds before creating a queue with the same name.
    See also: AWS API Documentation
    
    
    :example: response = client.delete_queue(
        QueueUrl='string'
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the Amazon SQS queue to delete.\nQueue URLs and names are case-sensitive.\n

    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_queue_attributes(QueueUrl=None, AttributeNames=None):
    """
    Gets attributes for the specified queue.
    Some actions take lists of parameters. These lists are specified using the param.n notation. Values of n are integers starting from 1. For example, a parameter list with two elements looks like this:
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_queue_attributes(
        QueueUrl='string',
        AttributeNames=[
            'All'|'Policy'|'VisibilityTimeout'|'MaximumMessageSize'|'MessageRetentionPeriod'|'ApproximateNumberOfMessages'|'ApproximateNumberOfMessagesNotVisible'|'CreatedTimestamp'|'LastModifiedTimestamp'|'QueueArn'|'ApproximateNumberOfMessagesDelayed'|'DelaySeconds'|'ReceiveMessageWaitTimeSeconds'|'RedrivePolicy'|'FifoQueue'|'ContentBasedDeduplication'|'KmsMasterKeyId'|'KmsDataKeyReusePeriodSeconds',
        ]
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the Amazon SQS queue whose attribute information is retrieved.\nQueue URLs and names are case-sensitive.\n

    :type AttributeNames: list
    :param AttributeNames: A list of attributes for which to retrieve information.\n\nNote\nIn the future, new attributes might be added. If you write code that calls this action, we recommend that you structure your code so that it can handle new attributes gracefully.\n\nThe following attributes are supported:\n\nAll - Returns all values.\nApproximateNumberOfMessages - Returns the approximate number of messages available for retrieval from the queue.\nApproximateNumberOfMessagesDelayed - Returns the approximate number of messages in the queue that are delayed and not available for reading immediately. This can happen when the queue is configured as a delay queue or when a message has been sent with a delay parameter.\nApproximateNumberOfMessagesNotVisible - Returns the approximate number of messages that are in flight. Messages are considered to be in flight if they have been sent to a client but have not yet been deleted or have not yet reached the end of their visibility window.\nCreatedTimestamp - Returns the time when the queue was created in seconds (epoch time ).\nDelaySeconds - Returns the default delay on the queue in seconds.\nLastModifiedTimestamp - Returns the time when the queue was last changed in seconds (epoch time ).\nMaximumMessageSize - Returns the limit of how many bytes a message can contain before Amazon SQS rejects it.\nMessageRetentionPeriod - Returns the length of time, in seconds, for which Amazon SQS retains a message.\nPolicy - Returns the policy of the queue.\nQueueArn - Returns the Amazon resource name (ARN) of the queue.\nReceiveMessageWaitTimeSeconds - Returns the length of time, in seconds, for which the ReceiveMessage action waits for a message to arrive.\nRedrivePolicy - Returns the string that includes the parameters for dead-letter queue functionality of the source queue. For more information about the redrive policy and dead-letter queues, see Using Amazon SQS Dead-Letter Queues in the Amazon Simple Queue Service Developer Guide .\ndeadLetterTargetArn - The Amazon Resource Name (ARN) of the dead-letter queue to which Amazon SQS moves messages after the value of maxReceiveCount is exceeded.\nmaxReceiveCount - The number of times a message is delivered to the source queue before being moved to the dead-letter queue. When the ReceiveCount for a message exceeds the maxReceiveCount for a queue, Amazon SQS moves the message to the dead-letter-queue.\n\n\nVisibilityTimeout - Returns the visibility timeout for the queue. For more information about the visibility timeout, see Visibility Timeout in the Amazon Simple Queue Service Developer Guide .\n\nThe following attributes apply only to server-side-encryption :\n\nKmsMasterKeyId - Returns the ID of an AWS-managed customer master key (CMK) for Amazon SQS or a custom CMK. For more information, see Key Terms .\nKmsDataKeyReusePeriodSeconds - Returns the length of time, in seconds, for which Amazon SQS can reuse a data key to encrypt or decrypt messages before calling AWS KMS again. For more information, see How Does the Data Key Reuse Period Work? .\n\nThe following attributes apply only to FIFO (first-in-first-out) queues :\n\nFifoQueue - Returns whether the queue is FIFO. For more information, see FIFO Queue Logic in the Amazon Simple Queue Service Developer Guide .\n\n\nNote\nTo determine whether a queue is FIFO , you can check whether QueueName ends with the .fifo suffix.\n\n\nContentBasedDeduplication - Returns whether content-based deduplication is enabled for the queue. For more information, see Exactly-Once Processing in the Amazon Simple Queue Service Developer Guide .\n\n\n(string) --\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'Attributes': {
        'string': 'string'
    }
}


Response Structure

(dict) --
A list of returned queue attributes.

Attributes (dict) --
A map of attributes to their respective values.

(string) --
(string) --










Exceptions

SQS.Client.exceptions.InvalidAttributeName


    :return: {
        'Attributes': {
            'string': 'string'
        }
    }
    
    
    :returns: 
    (string) --
    (string) --
    
    
    
    """
    pass

def get_queue_url(QueueName=None, QueueOwnerAWSAccountId=None):
    """
    Returns the URL of an existing Amazon SQS queue.
    To access a queue that belongs to another AWS account, use the QueueOwnerAWSAccountId parameter to specify the account ID of the queue\'s owner. The queue\'s owner must grant you permission to access the queue. For more information about shared queue access, see ``  AddPermission `` or see Allow Developers to Write Messages to a Shared Queue in the Amazon Simple Queue Service Developer Guide .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_queue_url(
        QueueName='string',
        QueueOwnerAWSAccountId='string'
    )
    
    
    :type QueueName: string
    :param QueueName: [REQUIRED]\nThe name of the queue whose URL must be fetched. Maximum 80 characters. Valid values: alphanumeric characters, hyphens (- ), and underscores (_ ).\nQueue URLs and names are case-sensitive.\n

    :type QueueOwnerAWSAccountId: string
    :param QueueOwnerAWSAccountId: The AWS account ID of the account that created the queue.

    :rtype: dict

ReturnsResponse Syntax
{
    'QueueUrl': 'string'
}


Response Structure

(dict) --
For more information, see Interpreting Responses in the Amazon Simple Queue Service Developer Guide .

QueueUrl (string) --
The URL of the queue.







Exceptions

SQS.Client.exceptions.QueueDoesNotExist


    :return: {
        'QueueUrl': 'string'
    }
    
    
    :returns: 
    SQS.Client.exceptions.QueueDoesNotExist
    
    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def list_dead_letter_source_queues(QueueUrl=None):
    """
    Returns a list of your queues that have the RedrivePolicy queue attribute configured with a dead-letter queue.
    For more information about using dead-letter queues, see Using Amazon SQS Dead-Letter Queues in the Amazon Simple Queue Service Developer Guide .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_dead_letter_source_queues(
        QueueUrl='string'
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of a dead-letter queue.\nQueue URLs and names are case-sensitive.\n

    :rtype: dict
ReturnsResponse Syntax{
    'queueUrls': [
        'string',
    ]
}


Response Structure

(dict) --A list of your dead letter source queues.

queueUrls (list) --A list of source queue URLs that have the RedrivePolicy queue attribute configured with a dead-letter queue.

(string) --







Exceptions

SQS.Client.exceptions.QueueDoesNotExist


    :return: {
        'queueUrls': [
            'string',
        ]
    }
    
    
    :returns: 
    SQS.Client.exceptions.QueueDoesNotExist
    
    """
    pass

def list_queue_tags(QueueUrl=None):
    """
    List all cost allocation tags added to the specified Amazon SQS queue. For an overview, see Tagging Your Amazon SQS Queues in the Amazon Simple Queue Service Developer Guide .
    See also: AWS API Documentation
    
    
    :example: response = client.list_queue_tags(
        QueueUrl='string'
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the queue.\n

    :rtype: dict
ReturnsResponse Syntax{
    'Tags': {
        'string': 'string'
    }
}


Response Structure

(dict) --
Tags (dict) --The list of all tags added to the specified queue.

(string) --
(string) --










    :return: {
        'Tags': {
            'string': 'string'
        }
    }
    
    
    """
    pass

def list_queues(QueueNamePrefix=None):
    """
    Returns a list of your queues. The maximum number of queues that can be returned is 1,000. If you specify a value for the optional QueueNamePrefix parameter, only queues with a name that begins with the specified value are returned.
    See also: AWS API Documentation
    
    
    :example: response = client.list_queues(
        QueueNamePrefix='string'
    )
    
    
    :type QueueNamePrefix: string
    :param QueueNamePrefix: A string to use for filtering the list results. Only those queues whose name begins with the specified string are returned.\nQueue URLs and names are case-sensitive.\n

    :rtype: dict
ReturnsResponse Syntax{
    'QueueUrls': [
        'string',
    ]
}


Response Structure

(dict) --A list of your queues.

QueueUrls (list) --A list of queue URLs, up to 1,000 entries.

(string) --








    :return: {
        'QueueUrls': [
            'string',
        ]
    }
    
    
    """
    pass

def purge_queue(QueueUrl=None):
    """
    Deletes the messages in a queue specified by the QueueURL parameter.
    Messages sent to the queue before you call PurgeQueue might be received but are deleted within the next minute.
    Messages sent to the queue after you call PurgeQueue might be deleted while the queue is being purged.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.purge_queue(
        QueueUrl='string'
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the queue from which the PurgeQueue action deletes messages.\nQueue URLs and names are case-sensitive.\n

    """
    pass

def receive_message(QueueUrl=None, AttributeNames=None, MessageAttributeNames=None, MaxNumberOfMessages=None, VisibilityTimeout=None, WaitTimeSeconds=None, ReceiveRequestAttemptId=None):
    """
    Retrieves one or more messages (up to 10), from the specified queue. Using the WaitTimeSeconds parameter enables long-poll support. For more information, see Amazon SQS Long Polling in the Amazon Simple Queue Service Developer Guide .
    Short poll is the default behavior where a weighted random set of machines is sampled on a ReceiveMessage call. Thus, only the messages on the sampled machines are returned. If the number of messages in the queue is small (fewer than 1,000), you most likely get fewer messages than you requested per ReceiveMessage call. If the number of messages in the queue is extremely small, you might not receive any messages in a particular ReceiveMessage response. If this happens, repeat the request.
    For each message returned, the response includes the following:
    The receipt handle is the identifier you must provide when deleting the message. For more information, see Queue and Message Identifiers in the Amazon Simple Queue Service Developer Guide .
    You can provide the VisibilityTimeout parameter in your request. The parameter is applied to the messages that Amazon SQS returns in the response. If you don\'t include the parameter, the overall visibility timeout for the queue is used for the returned messages. For more information, see Visibility Timeout in the Amazon Simple Queue Service Developer Guide .
    A message that isn\'t deleted or a message whose visibility isn\'t extended before the visibility timeout expires counts as a failed receive. Depending on the configuration of the queue, the message might be sent to the dead-letter queue.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.receive_message(
        QueueUrl='string',
        AttributeNames=[
            'All'|'Policy'|'VisibilityTimeout'|'MaximumMessageSize'|'MessageRetentionPeriod'|'ApproximateNumberOfMessages'|'ApproximateNumberOfMessagesNotVisible'|'CreatedTimestamp'|'LastModifiedTimestamp'|'QueueArn'|'ApproximateNumberOfMessagesDelayed'|'DelaySeconds'|'ReceiveMessageWaitTimeSeconds'|'RedrivePolicy'|'FifoQueue'|'ContentBasedDeduplication'|'KmsMasterKeyId'|'KmsDataKeyReusePeriodSeconds',
        ],
        MessageAttributeNames=[
            'string',
        ],
        MaxNumberOfMessages=123,
        VisibilityTimeout=123,
        WaitTimeSeconds=123,
        ReceiveRequestAttemptId='string'
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the Amazon SQS queue from which messages are received.\nQueue URLs and names are case-sensitive.\n

    :type AttributeNames: list
    :param AttributeNames: A list of attributes that need to be returned along with each message. These attributes include:\n\nAll - Returns all values.\nApproximateFirstReceiveTimestamp - Returns the time the message was first received from the queue (epoch time in milliseconds).\nApproximateReceiveCount - Returns the number of times a message has been received from the queue but not deleted.\nAWSTraceHeader - Returns the AWS X-Ray trace header string.\nSenderId\nFor an IAM user, returns the IAM user ID, for example ABCDEFGHI1JKLMNOPQ23R .\nFor an IAM role, returns the IAM role ID, for example ABCDE1F2GH3I4JK5LMNOP:i-a123b456 .\n\n\nSentTimestamp - Returns the time the message was sent to the queue (epoch time in milliseconds).\nMessageDeduplicationId - Returns the value provided by the producer that calls the `` SendMessage `` action.\nMessageGroupId - Returns the value provided by the producer that calls the `` SendMessage `` action. Messages with the same MessageGroupId are returned in sequence.\nSequenceNumber - Returns the value provided by Amazon SQS.\n\n\n(string) --\n\n

    :type MessageAttributeNames: list
    :param MessageAttributeNames: The name of the message attribute, where N is the index.\n\nThe name can contain alphanumeric characters and the underscore (_ ), hyphen (- ), and period (. ).\nThe name is case-sensitive and must be unique among all attribute names for the message.\nThe name must not start with AWS-reserved prefixes such as AWS. or Amazon. (or any casing variants).\nThe name must not start or end with a period (. ), and it should not have periods in succession (.. ).\nThe name can be up to 256 characters long.\n\nWhen using ReceiveMessage , you can send a list of attribute names to receive, or you can return all of the attributes by specifying All or .* in your request. You can also use all message attributes starting with a prefix, for example bar.* .\n\n(string) --\n\n

    :type MaxNumberOfMessages: integer
    :param MaxNumberOfMessages: The maximum number of messages to return. Amazon SQS never returns more messages than this value (however, fewer messages might be returned). Valid values: 1 to 10. Default: 1.

    :type VisibilityTimeout: integer
    :param VisibilityTimeout: The duration (in seconds) that the received messages are hidden from subsequent retrieve requests after being retrieved by a ReceiveMessage request.

    :type WaitTimeSeconds: integer
    :param WaitTimeSeconds: The duration (in seconds) for which the call waits for a message to arrive in the queue before returning. If a message is available, the call returns sooner than WaitTimeSeconds . If no messages are available and the wait time expires, the call returns successfully with an empty list of messages.

    :type ReceiveRequestAttemptId: string
    :param ReceiveRequestAttemptId: This parameter applies only to FIFO (first-in-first-out) queues.\nThe token used for deduplication of ReceiveMessage calls. If a networking issue occurs after a ReceiveMessage action, and instead of a response you receive a generic error, you can retry the same action with an identical ReceiveRequestAttemptId to retrieve the same set of messages, even if their visibility timeout has not yet expired.\n\nYou can use ReceiveRequestAttemptId only for 5 minutes after a ReceiveMessage action.\nWhen you set FifoQueue , a caller of the ReceiveMessage action can provide a ReceiveRequestAttemptId explicitly.\nIf a caller of the ReceiveMessage action doesn\'t provide a ReceiveRequestAttemptId , Amazon SQS generates a ReceiveRequestAttemptId .\nYou can retry the ReceiveMessage action with the same ReceiveRequestAttemptId if none of the messages have been modified (deleted or had their visibility changes).\nDuring a visibility timeout, subsequent calls with the same ReceiveRequestAttemptId return the same messages and receipt handles. If a retry occurs within the deduplication interval, it resets the visibility timeout. For more information, see Visibility Timeout in the Amazon Simple Queue Service Developer Guide .\n\n\nWarning\nIf a caller of the ReceiveMessage action still processes messages when the visibility timeout expires and messages become visible, another worker consuming from the same queue can receive the same messages and therefore process duplicates. Also, if a consumer whose message processing time is longer than the visibility timeout tries to delete the processed messages, the action fails with an error. To mitigate this effect, ensure that your application observes a safe threshold before the visibility timeout expires and extend the visibility timeout as necessary.\n\n\nWhile messages with a particular MessageGroupId are invisible, no more messages belonging to the same MessageGroupId are returned until the visibility timeout expires. You can still receive messages with another MessageGroupId as long as it is also visible.\nIf a caller of ReceiveMessage can\'t track the ReceiveRequestAttemptId , no retries work until the original visibility timeout expires. As a result, delays might occur but the messages in the queue remain in a strict order.\n\nThe length of ReceiveRequestAttemptId is 128 characters. ReceiveRequestAttemptId can contain alphanumeric characters (a-z , A-Z , 0-9 ) and punctuation (!'#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~ ).\nFor best practices of using ReceiveRequestAttemptId , see Using the ReceiveRequestAttemptId Request Parameter in the Amazon Simple Queue Service Developer Guide .\n

    :rtype: dict

ReturnsResponse Syntax
{
    'Messages': [
        {
            'MessageId': 'string',
            'ReceiptHandle': 'string',
            'MD5OfBody': 'string',
            'Body': 'string',
            'Attributes': {
                'string': 'string'
            },
            'MD5OfMessageAttributes': 'string',
            'MessageAttributes': {
                'string': {
                    'StringValue': 'string',
                    'BinaryValue': b'bytes',
                    'StringListValues': [
                        'string',
                    ],
                    'BinaryListValues': [
                        b'bytes',
                    ],
                    'DataType': 'string'
                }
            }
        },
    ]
}


Response Structure

(dict) --
A list of received messages.

Messages (list) --
A list of messages.

(dict) --
An Amazon SQS message.

MessageId (string) --
A unique identifier for the message. A MessageId is considered unique across all AWS accounts for an extended period of time.

ReceiptHandle (string) --
An identifier associated with the act of receiving the message. A new receipt handle is returned every time you receive a message. When deleting a message, you provide the last received receipt handle to delete the message.

MD5OfBody (string) --
An MD5 digest of the non-URL-encoded message body string.

Body (string) --
The message\'s contents (not URL-encoded).

Attributes (dict) --
A map of the attributes requested in ``  ReceiveMessage `` to their respective values. Supported attributes:

ApproximateReceiveCount
ApproximateFirstReceiveTimestamp
MessageDeduplicationId
MessageGroupId
SenderId
SentTimestamp
SequenceNumber


ApproximateFirstReceiveTimestamp and SentTimestamp are each returned as an integer representing the epoch time in milliseconds.


(string) --
(string) --




MD5OfMessageAttributes (string) --
An MD5 digest of the non-URL-encoded message attribute string. You can use this attribute to verify that Amazon SQS received the message correctly. Amazon SQS URL-decodes the message before creating the MD5 digest. For information about MD5, see RFC1321 .

MessageAttributes (dict) --
Each message attribute consists of a Name , Type , and Value . For more information, see Amazon SQS Message Attributes in the Amazon Simple Queue Service Developer Guide .

(string) --

(dict) --
The user-specified message attribute value. For string data types, the Value attribute has the same restrictions on the content as the message body. For more information, see ``  SendMessage .``

Name , type , value and the message body must not be empty or null. All parts of the message attribute, including Name , Type , and Value , are part of the message size restriction (256 KB or 262,144 bytes).


StringValue (string) --
Strings are Unicode with UTF-8 binary encoding. For a list of code values, see ASCII Printable Characters .

BinaryValue (bytes) --
Binary type attributes can store any binary data, such as compressed data, encrypted data, or images.

StringListValues (list) --
Not implemented. Reserved for future use.

(string) --


BinaryListValues (list) --
Not implemented. Reserved for future use.

(bytes) --


DataType (string) --
Amazon SQS supports the following logical data types: String , Number , and Binary . For the Number data type, you must use StringValue .
You can also append custom labels. For more information, see Amazon SQS Message Attributes in the Amazon Simple Queue Service Developer Guide .

















Exceptions

SQS.Client.exceptions.OverLimit


    :return: {
        'Messages': [
            {
                'MessageId': 'string',
                'ReceiptHandle': 'string',
                'MD5OfBody': 'string',
                'Body': 'string',
                'Attributes': {
                    'string': 'string'
                },
                'MD5OfMessageAttributes': 'string',
                'MessageAttributes': {
                    'string': {
                        'StringValue': 'string',
                        'BinaryValue': b'bytes',
                        'StringListValues': [
                            'string',
                        ],
                        'BinaryListValues': [
                            b'bytes',
                        ],
                        'DataType': 'string'
                    }
                }
            },
        ]
    }
    
    
    :returns: 
    QueueUrl (string) -- [REQUIRED]
    The URL of the Amazon SQS queue from which messages are received.
    Queue URLs and names are case-sensitive.
    
    AttributeNames (list) -- A list of attributes that need to be returned along with each message. These attributes include:
    
    All - Returns all values.
    ApproximateFirstReceiveTimestamp - Returns the time the message was first received from the queue (epoch time in milliseconds).
    ApproximateReceiveCount - Returns the number of times a message has been received from the queue but not deleted.
    AWSTraceHeader - Returns the AWS X-Ray trace header string.
    SenderId
    For an IAM user, returns the IAM user ID, for example ABCDEFGHI1JKLMNOPQ23R .
    For an IAM role, returns the IAM role ID, for example ABCDE1F2GH3I4JK5LMNOP:i-a123b456 .
    
    
    SentTimestamp - Returns the time the message was sent to the queue (epoch time in milliseconds).
    MessageDeduplicationId - Returns the value provided by the producer that calls the ``  SendMessage `` action.
    MessageGroupId - Returns the value provided by the producer that calls the ``  SendMessage `` action. Messages with the same MessageGroupId are returned in sequence.
    SequenceNumber - Returns the value provided by Amazon SQS.
    
    
    (string) --
    
    
    MessageAttributeNames (list) -- The name of the message attribute, where N is the index.
    
    The name can contain alphanumeric characters and the underscore (_ ), hyphen (- ), and period (. ).
    The name is case-sensitive and must be unique among all attribute names for the message.
    The name must not start with AWS-reserved prefixes such as AWS. or Amazon. (or any casing variants).
    The name must not start or end with a period (. ), and it should not have periods in succession (.. ).
    The name can be up to 256 characters long.
    
    When using ReceiveMessage , you can send a list of attribute names to receive, or you can return all of the attributes by specifying All or .* in your request. You can also use all message attributes starting with a prefix, for example bar.* .
    
    (string) --
    
    
    MaxNumberOfMessages (integer) -- The maximum number of messages to return. Amazon SQS never returns more messages than this value (however, fewer messages might be returned). Valid values: 1 to 10. Default: 1.
    VisibilityTimeout (integer) -- The duration (in seconds) that the received messages are hidden from subsequent retrieve requests after being retrieved by a ReceiveMessage request.
    WaitTimeSeconds (integer) -- The duration (in seconds) for which the call waits for a message to arrive in the queue before returning. If a message is available, the call returns sooner than WaitTimeSeconds . If no messages are available and the wait time expires, the call returns successfully with an empty list of messages.
    ReceiveRequestAttemptId (string) -- This parameter applies only to FIFO (first-in-first-out) queues.
    The token used for deduplication of ReceiveMessage calls. If a networking issue occurs after a ReceiveMessage action, and instead of a response you receive a generic error, you can retry the same action with an identical ReceiveRequestAttemptId to retrieve the same set of messages, even if their visibility timeout has not yet expired.
    
    You can use ReceiveRequestAttemptId only for 5 minutes after a ReceiveMessage action.
    When you set FifoQueue , a caller of the ReceiveMessage action can provide a ReceiveRequestAttemptId explicitly.
    If a caller of the ReceiveMessage action doesn\'t provide a ReceiveRequestAttemptId , Amazon SQS generates a ReceiveRequestAttemptId .
    You can retry the ReceiveMessage action with the same ReceiveRequestAttemptId if none of the messages have been modified (deleted or had their visibility changes).
    During a visibility timeout, subsequent calls with the same ReceiveRequestAttemptId return the same messages and receipt handles. If a retry occurs within the deduplication interval, it resets the visibility timeout. For more information, see Visibility Timeout in the Amazon Simple Queue Service Developer Guide .
    
    
    Warning
    If a caller of the ReceiveMessage action still processes messages when the visibility timeout expires and messages become visible, another worker consuming from the same queue can receive the same messages and therefore process duplicates. Also, if a consumer whose message processing time is longer than the visibility timeout tries to delete the processed messages, the action fails with an error. To mitigate this effect, ensure that your application observes a safe threshold before the visibility timeout expires and extend the visibility timeout as necessary.
    
    
    While messages with a particular MessageGroupId are invisible, no more messages belonging to the same MessageGroupId are returned until the visibility timeout expires. You can still receive messages with another MessageGroupId as long as it is also visible.
    If a caller of ReceiveMessage can\'t track the ReceiveRequestAttemptId , no retries work until the original visibility timeout expires. As a result, delays might occur but the messages in the queue remain in a strict order.
    
    The length of ReceiveRequestAttemptId is 128 characters. ReceiveRequestAttemptId can contain alphanumeric characters (a-z , A-Z , 0-9 ) and punctuation (!"#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~ ).
    For best practices of using ReceiveRequestAttemptId , see Using the ReceiveRequestAttemptId Request Parameter in the Amazon Simple Queue Service Developer Guide .
    
    
    """
    pass

def remove_permission(QueueUrl=None, Label=None):
    """
    Revokes any permissions in the queue policy that matches the specified Label parameter.
    See also: AWS API Documentation
    
    
    :example: response = client.remove_permission(
        QueueUrl='string',
        Label='string'
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the Amazon SQS queue from which permissions are removed.\nQueue URLs and names are case-sensitive.\n

    :type Label: string
    :param Label: [REQUIRED]\nThe identification of the permission to remove. This is the label added using the `` AddPermission `` action.\n

    :returns: 
    QueueUrl (string) -- [REQUIRED]
    The URL of the Amazon SQS queue from which permissions are removed.
    Queue URLs and names are case-sensitive.
    
    Label (string) -- [REQUIRED]
    The identification of the permission to remove. This is the label added using the ``  AddPermission `` action.
    
    
    """
    pass

def send_message(QueueUrl=None, MessageBody=None, DelaySeconds=None, MessageAttributes=None, MessageSystemAttributes=None, MessageDeduplicationId=None, MessageGroupId=None):
    """
    Delivers a message to the specified queue.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.send_message(
        QueueUrl='string',
        MessageBody='string',
        DelaySeconds=123,
        MessageAttributes={
            'string': {
                'StringValue': 'string',
                'BinaryValue': b'bytes',
                'StringListValues': [
                    'string',
                ],
                'BinaryListValues': [
                    b'bytes',
                ],
                'DataType': 'string'
            }
        },
        MessageSystemAttributes={
            'string': {
                'StringValue': 'string',
                'BinaryValue': b'bytes',
                'StringListValues': [
                    'string',
                ],
                'BinaryListValues': [
                    b'bytes',
                ],
                'DataType': 'string'
            }
        },
        MessageDeduplicationId='string',
        MessageGroupId='string'
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the Amazon SQS queue to which a message is sent.\nQueue URLs and names are case-sensitive.\n

    :type MessageBody: string
    :param MessageBody: [REQUIRED]\nThe message to send. The maximum string size is 256 KB.\n\nWarning\nA message can include only XML, JSON, and unformatted text. The following Unicode characters are allowed:\n\n#x9 | #xA | #xD | #x20 to #xD7FF | #xE000 to #xFFFD | #x10000 to #x10FFFF\nAny characters not included in this list will be rejected. For more information, see the W3C specification for characters .\n\n

    :type DelaySeconds: integer
    :param DelaySeconds: The length of time, in seconds, for which to delay a specific message. Valid values: 0 to 900. Maximum: 15 minutes. Messages with a positive DelaySeconds value become available for processing after the delay period is finished. If you don\'t specify a value, the default value for the queue applies.\n\nNote\nWhen you set FifoQueue , you can\'t set DelaySeconds per message. You can set this parameter only on a queue level.\n\n

    :type MessageAttributes: dict
    :param MessageAttributes: Each message attribute consists of a Name , Type , and Value . For more information, see Amazon SQS Message Attributes in the Amazon Simple Queue Service Developer Guide .\n\n(string) --\n(dict) --The user-specified message attribute value. For string data types, the Value attribute has the same restrictions on the content as the message body. For more information, see `` SendMessage .``\n\nName , type , value and the message body must not be empty or null. All parts of the message attribute, including Name , Type , and Value , are part of the message size restriction (256 KB or 262,144 bytes).\n\nStringValue (string) --Strings are Unicode with UTF-8 binary encoding. For a list of code values, see ASCII Printable Characters .\n\nBinaryValue (bytes) --Binary type attributes can store any binary data, such as compressed data, encrypted data, or images.\n\nStringListValues (list) --Not implemented. Reserved for future use.\n\n(string) --\n\n\nBinaryListValues (list) --Not implemented. Reserved for future use.\n\n(bytes) --\n\n\nDataType (string) -- [REQUIRED]Amazon SQS supports the following logical data types: String , Number , and Binary . For the Number data type, you must use StringValue .\nYou can also append custom labels. For more information, see Amazon SQS Message Attributes in the Amazon Simple Queue Service Developer Guide .\n\n\n\n\n\n\n

    :type MessageSystemAttributes: dict
    :param MessageSystemAttributes: The message system attribute to send. Each message system attribute consists of a Name , Type , and Value .\n\nWarning\n\nCurrently, the only supported message system attribute is AWSTraceHeader . Its type must be String and its value must be a correctly formatted AWS X-Ray trace string.\nThe size of a message system attribute doesn\'t count towards the total size of a message.\n\n\n\n(string) --\n(dict) --The user-specified message system attribute value. For string data types, the Value attribute has the same restrictions on the content as the message body. For more information, see `` SendMessage .``\n\nName , type , value and the message body must not be empty or null.\n\nStringValue (string) --Strings are Unicode with UTF-8 binary encoding. For a list of code values, see ASCII Printable Characters .\n\nBinaryValue (bytes) --Binary type attributes can store any binary data, such as compressed data, encrypted data, or images.\n\nStringListValues (list) --Not implemented. Reserved for future use.\n\n(string) --\n\n\nBinaryListValues (list) --Not implemented. Reserved for future use.\n\n(bytes) --\n\n\nDataType (string) -- [REQUIRED]Amazon SQS supports the following logical data types: String , Number , and Binary . For the Number data type, you must use StringValue .\nYou can also append custom labels. For more information, see Amazon SQS Message Attributes in the Amazon Simple Queue Service Developer Guide .\n\n\n\n\n\n\n

    :type MessageDeduplicationId: string
    :param MessageDeduplicationId: This parameter applies only to FIFO (first-in-first-out) queues.\nThe token used for deduplication of sent messages. If a message with a particular MessageDeduplicationId is sent successfully, any messages sent with the same MessageDeduplicationId are accepted successfully but aren\'t delivered during the 5-minute deduplication interval. For more information, see Exactly-Once Processing in the Amazon Simple Queue Service Developer Guide .\n\nEvery message must have a unique MessageDeduplicationId ,\nYou may provide a MessageDeduplicationId explicitly.\nIf you aren\'t able to provide a MessageDeduplicationId and you enable ContentBasedDeduplication for your queue, Amazon SQS uses a SHA-256 hash to generate the MessageDeduplicationId using the body of the message (but not the attributes of the message).\nIf you don\'t provide a MessageDeduplicationId and the queue doesn\'t have ContentBasedDeduplication set, the action fails with an error.\nIf the queue has ContentBasedDeduplication set, your MessageDeduplicationId overrides the generated one.\n\n\nWhen ContentBasedDeduplication is in effect, messages with identical content sent within the deduplication interval are treated as duplicates and only one copy of the message is delivered.\nIf you send one message with ContentBasedDeduplication enabled and then another message with a MessageDeduplicationId that is the same as the one generated for the first MessageDeduplicationId , the two messages are treated as duplicates and only one copy of the message is delivered.\n\n\nNote\nThe MessageDeduplicationId is available to the consumer of the message (this can be useful for troubleshooting delivery issues).\nIf a message is sent successfully but the acknowledgement is lost and the message is resent with the same MessageDeduplicationId after the deduplication interval, Amazon SQS can\'t detect duplicate messages.\nAmazon SQS continues to keep track of the message deduplication ID even after the message is received and deleted.\n\nThe length of MessageDeduplicationId is 128 characters. MessageDeduplicationId can contain alphanumeric characters (a-z , A-Z , 0-9 ) and punctuation (!'#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~ ).\nFor best practices of using MessageDeduplicationId , see Using the MessageDeduplicationId Property in the Amazon Simple Queue Service Developer Guide .\n

    :type MessageGroupId: string
    :param MessageGroupId: This parameter applies only to FIFO (first-in-first-out) queues.\nThe tag that specifies that a message belongs to a specific message group. Messages that belong to the same message group are processed in a FIFO manner (however, messages in different message groups might be processed out of order). To interleave multiple ordered streams within a single queue, use MessageGroupId values (for example, session data for multiple users). In this scenario, multiple consumers can process the queue, but the session data of each user is processed in a FIFO fashion.\n\nYou must associate a non-empty MessageGroupId with a message. If you don\'t provide a MessageGroupId , the action fails.\nReceiveMessage might return messages with multiple MessageGroupId values. For each MessageGroupId , the messages are sorted by time sent. The caller can\'t specify a MessageGroupId .\n\nThe length of MessageGroupId is 128 characters. Valid values: alphanumeric characters and punctuation (!'#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~) .\nFor best practices of using MessageGroupId , see Using the MessageGroupId Property in the Amazon Simple Queue Service Developer Guide .\n\nWarning\nMessageGroupId is required for FIFO queues. You can\'t use it for Standard queues.\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'MD5OfMessageBody': 'string',
    'MD5OfMessageAttributes': 'string',
    'MD5OfMessageSystemAttributes': 'string',
    'MessageId': 'string',
    'SequenceNumber': 'string'
}


Response Structure

(dict) --
The MD5OfMessageBody and MessageId elements.

MD5OfMessageBody (string) --
An MD5 digest of the non-URL-encoded message attribute string. You can use this attribute to verify that Amazon SQS received the message correctly. Amazon SQS URL-decodes the message before creating the MD5 digest. For information about MD5, see RFC1321 .

MD5OfMessageAttributes (string) --
An MD5 digest of the non-URL-encoded message attribute string. You can use this attribute to verify that Amazon SQS received the message correctly. Amazon SQS URL-decodes the message before creating the MD5 digest. For information about MD5, see RFC1321 .

MD5OfMessageSystemAttributes (string) --
An MD5 digest of the non-URL-encoded message system attribute string. You can use this attribute to verify that Amazon SQS received the message correctly. Amazon SQS URL-decodes the message before creating the MD5 digest.

MessageId (string) --
An attribute containing the MessageId of the message sent to the queue. For more information, see Queue and Message Identifiers in the Amazon Simple Queue Service Developer Guide .

SequenceNumber (string) --
This parameter applies only to FIFO (first-in-first-out) queues.
The large, non-consecutive number that Amazon SQS assigns to each message.
The length of SequenceNumber is 128 bits. SequenceNumber continues to increase for a particular MessageGroupId .







Exceptions

SQS.Client.exceptions.InvalidMessageContents
SQS.Client.exceptions.UnsupportedOperation


    :return: {
        'MD5OfMessageBody': 'string',
        'MD5OfMessageAttributes': 'string',
        'MD5OfMessageSystemAttributes': 'string',
        'MessageId': 'string',
        'SequenceNumber': 'string'
    }
    
    
    :returns: 
    SQS.Client.exceptions.InvalidMessageContents
    SQS.Client.exceptions.UnsupportedOperation
    
    """
    pass

def send_message_batch(QueueUrl=None, Entries=None):
    """
    Delivers up to ten messages to the specified queue. This is a batch version of ``  SendMessage .`` For a FIFO queue, multiple messages within a single batch are enqueued in the order they are sent.
    The result of sending each message is reported individually in the response. Because the batch request can result in a combination of successful and unsuccessful actions, you should check for batch errors even when the call returns an HTTP status code of 200 .
    The maximum allowed individual message size and the maximum total payload size (the sum of the individual lengths of all of the batched messages) are both 256 KB (262,144 bytes).
    If you don\'t specify the DelaySeconds parameter for an entry, Amazon SQS uses the default value for the queue.
    Some actions take lists of parameters. These lists are specified using the param.n notation. Values of n are integers starting from 1. For example, a parameter list with two elements looks like this:
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.send_message_batch(
        QueueUrl='string',
        Entries=[
            {
                'Id': 'string',
                'MessageBody': 'string',
                'DelaySeconds': 123,
                'MessageAttributes': {
                    'string': {
                        'StringValue': 'string',
                        'BinaryValue': b'bytes',
                        'StringListValues': [
                            'string',
                        ],
                        'BinaryListValues': [
                            b'bytes',
                        ],
                        'DataType': 'string'
                    }
                },
                'MessageSystemAttributes': {
                    'string': {
                        'StringValue': 'string',
                        'BinaryValue': b'bytes',
                        'StringListValues': [
                            'string',
                        ],
                        'BinaryListValues': [
                            b'bytes',
                        ],
                        'DataType': 'string'
                    }
                },
                'MessageDeduplicationId': 'string',
                'MessageGroupId': 'string'
            },
        ]
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the Amazon SQS queue to which batched messages are sent.\nQueue URLs and names are case-sensitive.\n

    :type Entries: list
    :param Entries: [REQUIRED]\nA list of `` SendMessageBatchRequestEntry `` items.\n\n(dict) --Contains the details of a single Amazon SQS message along with an Id .\n\nId (string) -- [REQUIRED]An identifier for a message in this batch used to communicate the result.\n\nNote\nThe Id s of a batch request need to be unique within a request\nThis identifier can have up to 80 characters. The following characters are accepted: alphanumeric characters, hyphens(-), and underscores (_).\n\n\nMessageBody (string) -- [REQUIRED]The body of the message.\n\nDelaySeconds (integer) --The length of time, in seconds, for which a specific message is delayed. Valid values: 0 to 900. Maximum: 15 minutes. Messages with a positive DelaySeconds value become available for processing after the delay period is finished. If you don\'t specify a value, the default value for the queue is applied.\n\nNote\nWhen you set FifoQueue , you can\'t set DelaySeconds per message. You can set this parameter only on a queue level.\n\n\nMessageAttributes (dict) --Each message attribute consists of a Name , Type , and Value . For more information, see Amazon SQS Message Attributes in the Amazon Simple Queue Service Developer Guide .\n\n(string) --\n(dict) --The user-specified message attribute value. For string data types, the Value attribute has the same restrictions on the content as the message body. For more information, see `` SendMessage .``\n\nName , type , value and the message body must not be empty or null. All parts of the message attribute, including Name , Type , and Value , are part of the message size restriction (256 KB or 262,144 bytes).\n\nStringValue (string) --Strings are Unicode with UTF-8 binary encoding. For a list of code values, see ASCII Printable Characters .\n\nBinaryValue (bytes) --Binary type attributes can store any binary data, such as compressed data, encrypted data, or images.\n\nStringListValues (list) --Not implemented. Reserved for future use.\n\n(string) --\n\n\nBinaryListValues (list) --Not implemented. Reserved for future use.\n\n(bytes) --\n\n\nDataType (string) -- [REQUIRED]Amazon SQS supports the following logical data types: String , Number , and Binary . For the Number data type, you must use StringValue .\nYou can also append custom labels. For more information, see Amazon SQS Message Attributes in the Amazon Simple Queue Service Developer Guide .\n\n\n\n\n\n\n\nMessageSystemAttributes (dict) --The message system attribute to send Each message system attribute consists of a Name , Type , and Value .\n\nWarning\n\nCurrently, the only supported message system attribute is AWSTraceHeader . Its type must be String and its value must be a correctly formatted AWS X-Ray trace string.\nThe size of a message system attribute doesn\'t count towards the total size of a message.\n\n\n\n(string) --\n(dict) --The user-specified message system attribute value. For string data types, the Value attribute has the same restrictions on the content as the message body. For more information, see `` SendMessage .``\n\nName , type , value and the message body must not be empty or null.\n\nStringValue (string) --Strings are Unicode with UTF-8 binary encoding. For a list of code values, see ASCII Printable Characters .\n\nBinaryValue (bytes) --Binary type attributes can store any binary data, such as compressed data, encrypted data, or images.\n\nStringListValues (list) --Not implemented. Reserved for future use.\n\n(string) --\n\n\nBinaryListValues (list) --Not implemented. Reserved for future use.\n\n(bytes) --\n\n\nDataType (string) -- [REQUIRED]Amazon SQS supports the following logical data types: String , Number , and Binary . For the Number data type, you must use StringValue .\nYou can also append custom labels. For more information, see Amazon SQS Message Attributes in the Amazon Simple Queue Service Developer Guide .\n\n\n\n\n\n\n\nMessageDeduplicationId (string) --This parameter applies only to FIFO (first-in-first-out) queues.\nThe token used for deduplication of messages within a 5-minute minimum deduplication interval. If a message with a particular MessageDeduplicationId is sent successfully, subsequent messages with the same MessageDeduplicationId are accepted successfully but aren\'t delivered. For more information, see Exactly-Once Processing in the Amazon Simple Queue Service Developer Guide .\n\nEvery message must have a unique MessageDeduplicationId ,\nYou may provide a MessageDeduplicationId explicitly.\nIf you aren\'t able to provide a MessageDeduplicationId and you enable ContentBasedDeduplication for your queue, Amazon SQS uses a SHA-256 hash to generate the MessageDeduplicationId using the body of the message (but not the attributes of the message).\nIf you don\'t provide a MessageDeduplicationId and the queue doesn\'t have ContentBasedDeduplication set, the action fails with an error.\nIf the queue has ContentBasedDeduplication set, your MessageDeduplicationId overrides the generated one.\n\n\nWhen ContentBasedDeduplication is in effect, messages with identical content sent within the deduplication interval are treated as duplicates and only one copy of the message is delivered.\nIf you send one message with ContentBasedDeduplication enabled and then another message with a MessageDeduplicationId that is the same as the one generated for the first MessageDeduplicationId , the two messages are treated as duplicates and only one copy of the message is delivered.\n\n\nNote\nThe MessageDeduplicationId is available to the consumer of the message (this can be useful for troubleshooting delivery issues).\nIf a message is sent successfully but the acknowledgement is lost and the message is resent with the same MessageDeduplicationId after the deduplication interval, Amazon SQS can\'t detect duplicate messages.\nAmazon SQS continues to keep track of the message deduplication ID even after the message is received and deleted.\n\nThe length of MessageDeduplicationId is 128 characters. MessageDeduplicationId can contain alphanumeric characters (a-z , A-Z , 0-9 ) and punctuation (!'#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~ ).\nFor best practices of using MessageDeduplicationId , see Using the MessageDeduplicationId Property in the Amazon Simple Queue Service Developer Guide .\n\nMessageGroupId (string) --This parameter applies only to FIFO (first-in-first-out) queues.\nThe tag that specifies that a message belongs to a specific message group. Messages that belong to the same message group are processed in a FIFO manner (however, messages in different message groups might be processed out of order). To interleave multiple ordered streams within a single queue, use MessageGroupId values (for example, session data for multiple users). In this scenario, multiple consumers can process the queue, but the session data of each user is processed in a FIFO fashion.\n\nYou must associate a non-empty MessageGroupId with a message. If you don\'t provide a MessageGroupId , the action fails.\nReceiveMessage might return messages with multiple MessageGroupId values. For each MessageGroupId , the messages are sorted by time sent. The caller can\'t specify a MessageGroupId .\n\nThe length of MessageGroupId is 128 characters. Valid values: alphanumeric characters and punctuation (!'#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~) .\nFor best practices of using MessageGroupId , see Using the MessageGroupId Property in the Amazon Simple Queue Service Developer Guide .\n\nWarning\nMessageGroupId is required for FIFO queues. You can\'t use it for Standard queues.\n\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'Successful': [
        {
            'Id': 'string',
            'MessageId': 'string',
            'MD5OfMessageBody': 'string',
            'MD5OfMessageAttributes': 'string',
            'MD5OfMessageSystemAttributes': 'string',
            'SequenceNumber': 'string'
        },
    ],
    'Failed': [
        {
            'Id': 'string',
            'SenderFault': True|False,
            'Code': 'string',
            'Message': 'string'
        },
    ]
}


Response Structure

(dict) --
For each message in the batch, the response contains a ``  SendMessageBatchResultEntry `` tag if the message succeeds or a ``  BatchResultErrorEntry `` tag if the message fails.

Successful (list) --
A list of ``  SendMessageBatchResultEntry `` items.

(dict) --
Encloses a MessageId for a successfully-enqueued message in a ``  SendMessageBatch .``

Id (string) --
An identifier for the message in this batch.

MessageId (string) --
An identifier for the message.

MD5OfMessageBody (string) --
An MD5 digest of the non-URL-encoded message attribute string. You can use this attribute to verify that Amazon SQS received the message correctly. Amazon SQS URL-decodes the message before creating the MD5 digest. For information about MD5, see RFC1321 .

MD5OfMessageAttributes (string) --
An MD5 digest of the non-URL-encoded message attribute string. You can use this attribute to verify that Amazon SQS received the message correctly. Amazon SQS URL-decodes the message before creating the MD5 digest. For information about MD5, see RFC1321 .

MD5OfMessageSystemAttributes (string) --
An MD5 digest of the non-URL-encoded message system attribute string. You can use this attribute to verify that Amazon SQS received the message correctly. Amazon SQS URL-decodes the message before creating the MD5 digest. For information about MD5, see RFC1321 .

SequenceNumber (string) --
This parameter applies only to FIFO (first-in-first-out) queues.
The large, non-consecutive number that Amazon SQS assigns to each message.
The length of SequenceNumber is 128 bits. As SequenceNumber continues to increase for a particular MessageGroupId .





Failed (list) --
A list of ``  BatchResultErrorEntry `` items with error details about each message that can\'t be enqueued.

(dict) --
Gives a detailed description of the result of an action on each entry in the request.

Id (string) --
The Id of an entry in a batch request.

SenderFault (boolean) --
Specifies whether the error happened due to the producer.

Code (string) --
An error code representing why the action failed on this entry.

Message (string) --
A message explaining why the action failed on this entry.











Exceptions

SQS.Client.exceptions.TooManyEntriesInBatchRequest
SQS.Client.exceptions.EmptyBatchRequest
SQS.Client.exceptions.BatchEntryIdsNotDistinct
SQS.Client.exceptions.BatchRequestTooLong
SQS.Client.exceptions.InvalidBatchEntryId
SQS.Client.exceptions.UnsupportedOperation


    :return: {
        'Successful': [
            {
                'Id': 'string',
                'MessageId': 'string',
                'MD5OfMessageBody': 'string',
                'MD5OfMessageAttributes': 'string',
                'MD5OfMessageSystemAttributes': 'string',
                'SequenceNumber': 'string'
            },
        ],
        'Failed': [
            {
                'Id': 'string',
                'SenderFault': True|False,
                'Code': 'string',
                'Message': 'string'
            },
        ]
    }
    
    
    :returns: 
    SQS.Client.exceptions.TooManyEntriesInBatchRequest
    SQS.Client.exceptions.EmptyBatchRequest
    SQS.Client.exceptions.BatchEntryIdsNotDistinct
    SQS.Client.exceptions.BatchRequestTooLong
    SQS.Client.exceptions.InvalidBatchEntryId
    SQS.Client.exceptions.UnsupportedOperation
    
    """
    pass

def set_queue_attributes(QueueUrl=None, Attributes=None):
    """
    Sets the value of one or more queue attributes. When you change a queue\'s attributes, the change can take up to 60 seconds for most of the attributes to propagate throughout the Amazon SQS system. Changes made to the MessageRetentionPeriod attribute can take up to 15 minutes.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.set_queue_attributes(
        QueueUrl='string',
        Attributes={
            'string': 'string'
        }
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the Amazon SQS queue whose attributes are set.\nQueue URLs and names are case-sensitive.\n

    :type Attributes: dict
    :param Attributes: [REQUIRED]\nA map of attributes to set.\nThe following lists the names, descriptions, and values of the special request parameters that the SetQueueAttributes action uses:\n\nDelaySeconds - The length of time, in seconds, for which the delivery of all messages in the queue is delayed. Valid values: An integer from 0 to 900 (15 minutes). Default: 0.\nMaximumMessageSize - The limit of how many bytes a message can contain before Amazon SQS rejects it. Valid values: An integer from 1,024 bytes (1 KiB) up to 262,144 bytes (256 KiB). Default: 262,144 (256 KiB).\nMessageRetentionPeriod - The length of time, in seconds, for which Amazon SQS retains a message. Valid values: An integer representing seconds, from 60 (1 minute) to 1,209,600 (14 days). Default: 345,600 (4 days).\nPolicy - The queue\'s policy. A valid AWS policy. For more information about policy structure, see Overview of AWS IAM Policies in the Amazon IAM User Guide .\nReceiveMessageWaitTimeSeconds - The length of time, in seconds, for which a `` ReceiveMessage `` action waits for a message to arrive. Valid values: an integer from 0 to 20 (seconds). Default: 0.\nRedrivePolicy - The string that includes the parameters for the dead-letter queue functionality of the source queue. For more information about the redrive policy and dead-letter queues, see Using Amazon SQS Dead-Letter Queues in the Amazon Simple Queue Service Developer Guide .\ndeadLetterTargetArn - The Amazon Resource Name (ARN) of the dead-letter queue to which Amazon SQS moves messages after the value of maxReceiveCount is exceeded.\nmaxReceiveCount - The number of times a message is delivered to the source queue before being moved to the dead-letter queue. When the ReceiveCount for a message exceeds the maxReceiveCount for a queue, Amazon SQS moves the message to the dead-letter-queue.\n\n\n\n\nNote\nThe dead-letter queue of a FIFO queue must also be a FIFO queue. Similarly, the dead-letter queue of a standard queue must also be a standard queue.\n\n\nVisibilityTimeout - The visibility timeout for the queue, in seconds. Valid values: an integer from 0 to 43,200 (12 hours). Default: 30. For more information about the visibility timeout, see Visibility Timeout in the Amazon Simple Queue Service Developer Guide .\n\nThe following attributes apply only to server-side-encryption :\n\nKmsMasterKeyId - The ID of an AWS-managed customer master key (CMK) for Amazon SQS or a custom CMK. For more information, see Key Terms . While the alias of the AWS-managed CMK for Amazon SQS is always alias/aws/sqs , the alias of a custom CMK can, for example, be ``alias/MyAlias `` . For more examples, see KeyId in the AWS Key Management Service API Reference .\nKmsDataKeyReusePeriodSeconds - The length of time, in seconds, for which Amazon SQS can reuse a data key to encrypt or decrypt messages before calling AWS KMS again. An integer representing seconds, between 60 seconds (1 minute) and 86,400 seconds (24 hours). Default: 300 (5 minutes). A shorter time period provides better security but results in more calls to KMS which might incur charges after Free Tier. For more information, see How Does the Data Key Reuse Period Work? .\n\nThe following attribute applies only to FIFO (first-in-first-out) queues :\n\nContentBasedDeduplication - Enables content-based deduplication. For more information, see Exactly-Once Processing in the Amazon Simple Queue Service Developer Guide .\nEvery message must have a unique MessageDeduplicationId ,\nYou may provide a MessageDeduplicationId explicitly.\nIf you aren\'t able to provide a MessageDeduplicationId and you enable ContentBasedDeduplication for your queue, Amazon SQS uses a SHA-256 hash to generate the MessageDeduplicationId using the body of the message (but not the attributes of the message).\nIf you don\'t provide a MessageDeduplicationId and the queue doesn\'t have ContentBasedDeduplication set, the action fails with an error.\nIf the queue has ContentBasedDeduplication set, your MessageDeduplicationId overrides the generated one.\n\n\nWhen ContentBasedDeduplication is in effect, messages with identical content sent within the deduplication interval are treated as duplicates and only one copy of the message is delivered.\nIf you send one message with ContentBasedDeduplication enabled and then another message with a MessageDeduplicationId that is the same as the one generated for the first MessageDeduplicationId , the two messages are treated as duplicates and only one copy of the message is delivered.\n\n\n\n\n(string) --\n(string) --\n\n\n\n

    :returns: 
    QueueUrl (string) -- [REQUIRED]
    The URL of the Amazon SQS queue whose attributes are set.
    Queue URLs and names are case-sensitive.
    
    Attributes (dict) -- [REQUIRED]
    A map of attributes to set.
    The following lists the names, descriptions, and values of the special request parameters that the SetQueueAttributes action uses:
    
    DelaySeconds - The length of time, in seconds, for which the delivery of all messages in the queue is delayed. Valid values: An integer from 0 to 900 (15 minutes). Default: 0.
    MaximumMessageSize - The limit of how many bytes a message can contain before Amazon SQS rejects it. Valid values: An integer from 1,024 bytes (1 KiB) up to 262,144 bytes (256 KiB). Default: 262,144 (256 KiB).
    MessageRetentionPeriod - The length of time, in seconds, for which Amazon SQS retains a message. Valid values: An integer representing seconds, from 60 (1 minute) to 1,209,600 (14 days). Default: 345,600 (4 days).
    Policy - The queue\'s policy. A valid AWS policy. For more information about policy structure, see Overview of AWS IAM Policies in the Amazon IAM User Guide .
    ReceiveMessageWaitTimeSeconds - The length of time, in seconds, for which a ``  ReceiveMessage `` action waits for a message to arrive. Valid values: an integer from 0 to 20 (seconds). Default: 0.
    RedrivePolicy - The string that includes the parameters for the dead-letter queue functionality of the source queue. For more information about the redrive policy and dead-letter queues, see Using Amazon SQS Dead-Letter Queues in the Amazon Simple Queue Service Developer Guide .
    deadLetterTargetArn - The Amazon Resource Name (ARN) of the dead-letter queue to which Amazon SQS moves messages after the value of maxReceiveCount is exceeded.
    maxReceiveCount - The number of times a message is delivered to the source queue before being moved to the dead-letter queue. When the ReceiveCount for a message exceeds the maxReceiveCount for a queue, Amazon SQS moves the message to the dead-letter-queue.
    
    
    
    
    Note
    The dead-letter queue of a FIFO queue must also be a FIFO queue. Similarly, the dead-letter queue of a standard queue must also be a standard queue.
    
    
    VisibilityTimeout - The visibility timeout for the queue, in seconds. Valid values: an integer from 0 to 43,200 (12 hours). Default: 30. For more information about the visibility timeout, see Visibility Timeout in the Amazon Simple Queue Service Developer Guide .
    
    The following attributes apply only to server-side-encryption :
    
    KmsMasterKeyId - The ID of an AWS-managed customer master key (CMK) for Amazon SQS or a custom CMK. For more information, see Key Terms . While the alias of the AWS-managed CMK for Amazon SQS is always alias/aws/sqs , the alias of a custom CMK can, for example, be ``alias/MyAlias `` . For more examples, see KeyId in the AWS Key Management Service API Reference .
    KmsDataKeyReusePeriodSeconds - The length of time, in seconds, for which Amazon SQS can reuse a data key to encrypt or decrypt messages before calling AWS KMS again. An integer representing seconds, between 60 seconds (1 minute) and 86,400 seconds (24 hours). Default: 300 (5 minutes). A shorter time period provides better security but results in more calls to KMS which might incur charges after Free Tier. For more information, see How Does the Data Key Reuse Period Work? .
    
    The following attribute applies only to FIFO (first-in-first-out) queues :
    
    ContentBasedDeduplication - Enables content-based deduplication. For more information, see Exactly-Once Processing in the Amazon Simple Queue Service Developer Guide .
    Every message must have a unique MessageDeduplicationId ,
    You may provide a MessageDeduplicationId explicitly.
    If you aren\'t able to provide a MessageDeduplicationId and you enable ContentBasedDeduplication for your queue, Amazon SQS uses a SHA-256 hash to generate the MessageDeduplicationId using the body of the message (but not the attributes of the message).
    If you don\'t provide a MessageDeduplicationId and the queue doesn\'t have ContentBasedDeduplication set, the action fails with an error.
    If the queue has ContentBasedDeduplication set, your MessageDeduplicationId overrides the generated one.
    
    
    When ContentBasedDeduplication is in effect, messages with identical content sent within the deduplication interval are treated as duplicates and only one copy of the message is delivered.
    If you send one message with ContentBasedDeduplication enabled and then another message with a MessageDeduplicationId that is the same as the one generated for the first MessageDeduplicationId , the two messages are treated as duplicates and only one copy of the message is delivered.
    
    
    
    
    (string) --
    (string) --
    
    
    
    
    
    """
    pass

def tag_queue(QueueUrl=None, Tags=None):
    """
    Add cost allocation tags to the specified Amazon SQS queue. For an overview, see Tagging Your Amazon SQS Queues in the Amazon Simple Queue Service Developer Guide .
    When you use queue tags, keep the following guidelines in mind:
    For a full list of tag restrictions, see Limits Related to Queues in the Amazon Simple Queue Service Developer Guide .
    See also: AWS API Documentation
    
    
    :example: response = client.tag_queue(
        QueueUrl='string',
        Tags={
            'string': 'string'
        }
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the queue.\n

    :type Tags: dict
    :param Tags: [REQUIRED]\nThe list of tags to be added to the specified queue.\n\n(string) --\n(string) --\n\n\n\n

    :returns: 
    QueueUrl (string) -- [REQUIRED]
    The URL of the queue.
    
    Tags (dict) -- [REQUIRED]
    The list of tags to be added to the specified queue.
    
    (string) --
    (string) --
    
    
    
    
    
    """
    pass

def untag_queue(QueueUrl=None, TagKeys=None):
    """
    Remove cost allocation tags from the specified Amazon SQS queue. For an overview, see Tagging Your Amazon SQS Queues in the Amazon Simple Queue Service Developer Guide .
    See also: AWS API Documentation
    
    
    :example: response = client.untag_queue(
        QueueUrl='string',
        TagKeys=[
            'string',
        ]
    )
    
    
    :type QueueUrl: string
    :param QueueUrl: [REQUIRED]\nThe URL of the queue.\n

    :type TagKeys: list
    :param TagKeys: [REQUIRED]\nThe list of tags to be removed from the specified queue.\n\n(string) --\n\n

    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def send_ssh_public_key(InstanceId=None, InstanceOSUser=None, SSHPublicKey=None, AvailabilityZone=None):
    """
    Pushes an SSH public key to a particular OS user on a given EC2 instance for 60 seconds.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.send_ssh_public_key(
        InstanceId='string',
        InstanceOSUser='string',
        SSHPublicKey='string',
        AvailabilityZone='string'
    )
    
    
    :type InstanceId: string
    :param InstanceId: [REQUIRED]\nThe EC2 instance you wish to publish the SSH key to.\n

    :type InstanceOSUser: string
    :param InstanceOSUser: [REQUIRED]\nThe OS user on the EC2 instance whom the key may be used to authenticate as.\n

    :type SSHPublicKey: string
    :param SSHPublicKey: [REQUIRED]\nThe public key to be published to the instance. To use it after publication you must have the matching private key.\n

    :type AvailabilityZone: string
    :param AvailabilityZone: [REQUIRED]\nThe availability zone the EC2 instance was launched in.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'RequestId': 'string',
    'Success': True|False
}


Response Structure

(dict) --

RequestId (string) --
The request ID as logged by EC2 Connect. Please provide this when contacting AWS Support.

Success (boolean) --
Indicates request success.







Exceptions

EC2InstanceConnect.Client.exceptions.AuthException
EC2InstanceConnect.Client.exceptions.InvalidArgsException
EC2InstanceConnect.Client.exceptions.ServiceException
EC2InstanceConnect.Client.exceptions.ThrottlingException
EC2InstanceConnect.Client.exceptions.EC2InstanceNotFoundException


    :return: {
        'RequestId': 'string',
        'Success': True|False
    }
    
    
    :returns: 
    EC2InstanceConnect.Client.exceptions.AuthException
    EC2InstanceConnect.Client.exceptions.InvalidArgsException
    EC2InstanceConnect.Client.exceptions.ServiceException
    EC2InstanceConnect.Client.exceptions.ThrottlingException
    EC2InstanceConnect.Client.exceptions.EC2InstanceNotFoundException
    
    """
    pass

